@@ -17,8 +17,6 @@
 
 from dataclasses import dataclass
 
-# pylint: disable=invalid-name
-# pylint: disable=line-too-long
 
 @dataclass(frozen=True)
 class _Namespaces:
@@ -80,6 +78,8 @@ class _Namespaces:
     HASHES_SHA512: str = 'urn:xmpp:hash-function-text-names:sha-512'
     HASHES_SHA3_256: str = 'urn:xmpp:hash-function-text-names:sha3-256'
     HASHES_SHA3_512: str = 'urn:xmpp:hash-function-text-names:sha3-512'
+    HATS: str = 'urn:xmpp:hats:0'
+    HATS_LEGACY: str = 'xmpp:prosody.im/protocol/hats:1'
     HINTS: str = 'urn:xmpp:hints'
     HTTPUPLOAD_0: str = 'urn:xmpp:http:upload:0'
     HTTP_AUTH: str = 'http://jabber.org/protocol/http-auth'
@@ -94,6 +94,7 @@ class _Namespaces:
     JINGLE_IBB: str = 'urn:xmpp:jingle:transports:ibb:1'
     JINGLE_ICE_UDP: str = 'urn:xmpp:jingle:transports:ice-udp:1'
     JINGLE_RAW_UDP: str = 'urn:xmpp:jingle:transports:raw-udp:1'
+    JINGLE_RTCP_FB: str = 'urn:xmpp:jingle:apps:rtp:rtcp-fb:0'
     JINGLE_RTP: str = 'urn:xmpp:jingle:apps:rtp:1'
     JINGLE_RTP_AUDIO: str = 'urn:xmpp:jingle:apps:rtp:audio'
     JINGLE_RTP_VIDEO: str = 'urn:xmpp:jingle:apps:rtp:video'
@@ -104,7 +105,10 @@ class _Namespaces:
     MAM_1: str = 'urn:xmpp:mam:1'
     MAM_2: str = 'urn:xmpp:mam:2'
     MESSAGE_MODERATE: str = 'urn:xmpp:message-moderate:0'
+    MESSAGE_MODERATE_1: str = 'urn:xmpp:message-moderate:1'
     MESSAGE_RETRACT: str = 'urn:xmpp:message-retract:0'
+    MESSAGE_RETRACT_1: str = 'urn:xmpp:message-retract:1'
+    MDS: str = 'urn:xmpp:mds:displayed:0'
     MOOD: str = 'http://jabber.org/protocol/mood'
     MSG_HINTS: str = 'urn:xmpp:hints'
     MUCLUMBUS: str = 'https://xmlns.zombofant.net/muclumbus/search/1.0'
@@ -153,6 +157,7 @@ class _Namespaces:
     SEARCH: str = 'jabber:iq:search'
     SECLABEL: str = 'urn:xmpp:sec-label:0'
     SECLABEL_CATALOG: str = 'urn:xmpp:sec-label:catalog:2'
+    SERVICE_DISCOVERY: str = 'urn:xmpp:extdisco:2'
     SESSION: str = 'urn:ietf:params:xml:ns:xmpp-session'
     SFS: str = 'urn:xmpp:sfs:0'
     SID: str = 'urn:xmpp:sid:0'
